<?php



require_once 'Classes/Queries/ConeQueryParameters.php';



class ObsSetParameters extends ConeQueryParameters
{
  // PUBLIC

  public function __construct( ObsSetParameters $rhs = null )
  {
    parent::__construct( $rhs );

    $this->pulsar_name = '';
    $this->cals_window = 30;

    if( $rhs != null )
      $this->Copy( $rhs );
  }
  public function Copy( ObsSetParameters $rhs )
  {
    parent::Copy( $rhs );

    $this->pulsar_name = $rhs->pulsar_name;
    $this->cals_window = $rhs->cals_window;
  }

  public function GetPulsarName() { return $this->pulsar_name; }
  public function SetPulsarName( $s_pulsar_name ) { $this->pulsar_name = $s_pulsar_name; }
  
  public function GetCalsWindow() { return $this->cals_window; }
  public function SetCalsWindow( $s_cals_window ) { $this->cals_window = $s_cals_window; }
  
  public function ReadForm( $form_data )
  {
    // Read in the coordinates
	
    $ra = new Angle();
    $dec = new Angle();
    $ra->FromHMS( $form_data['ra_hour'], $form_data['ra_min'], $form_data['ra_sec'] );
    $dec->FromDMS( $form_data['dec_deg'], $form_data['dec_min'], $form_data['dec_sec'] );
    $coords = new SkyCoord();
    $coords->SetRA( $ra );
    $coords->SetDEC( $dec );
    $this->SetCoordinates( $coords );
    
    $this->SetPulsarName( $form_data['pulsar_name'] );
    
    if( $form_data['add_cals'] == 'on' )
      $this->SetCalsWindow( $form_data['cals_window'] );
    else
      $this->SetCalsWindow( null );
    
    $this->SetProjectID( $form_data['project_id'] );
    
    $this->SetProjectID( $form_data['project_id'] );

    $this->SetSearchRadius( $form_data['search_radius'] );
    
    if( isset( $form_data['bands'] ) )
    {
      foreach( $form_data['bands'] as $next_band_name )
      {
        foreach( Band::$valid_bands as $next_valid )
          if( $next_valid->GetName() == $next_band_name )
            $this->AddBand( new Band( $next_valid ) );
      }
    }
    
    $this->SetDateRange( $this->MakeDateRange( $form_data['from_day'],
	                             $form_data['from_month'],
	                             $form_data['from_year'],
                                     $form_data['to_day'],
	                             $form_data['to_month'],
	                             $form_data['to_year'] ) );
    
    $this->SetOrderDirection( $form_data['order_dir'] );
    $this->SetOrderColumn( $form_data['order_col'] );
    
    $this->SetObsMode( $form_data['obs_mode'] );
    
    $this->SetDataType( $form_data['data_type'] );

    if( is_array( $form_data['bands'] ) )
    {
      foreach( $form_data['bands']  as $next_bandname )
      {
	if( $next_bandname == 'Any' )
	{
	  $this->bands = Band::$valid_bands;
	  break;
	}
	else
	  foreach( Band::$valid_bands as $next_valid_band )
	    if( $next_bandname == $next_valid_band->GetName() )
	      $this->bands[] = $next_valid_band;
      }
    }
  }

  // PRIVATE

  private $pulsar_name;
  private $cals_window;
  
  private function MakeDateRange( $fd, $fm, $fy, $td, $tm, $ty )
  {
    $from_date = new Date();
    $from_date->FromDMYString( $fd . '/' . $fm . '/' . $fy );

    $to_date = new Date();
    $to_date->FromDMYString( $td . '/' . $tm . '/' . $ty );

    $range = new DateRange();
    $range->SetFromDate( $from_date );
    $range->SetToDate( $to_date );

    return $range;
  }
};

?>